@@ -39,19 +39,19 @@ int main (int argc, char **argv)
     auto aboutData = KAboutData {
         QStringLiteral("kronometer"),   // componentName
         i18nc("KAboutData display name", "Kronometer"),
-        QStringLiteral("2.1.2"),    // version
+        QStringLiteral("2.1.3"),    // version
         i18n("Kronometer is a simple stopwatch application"), // shortDescription
         KAboutLicense::GPL_V2,    // licenseType
         i18n("Copyright (C) 2014-2016 Elvis Angelaccio"),    // copyrightStatement
         {},  // otherText
-        QStringLiteral("http://aelog.org/kronometer")   // homePageAddress
+        QStringLiteral("https://eang.it/kronometer")   // homePageAddress
     };
 
     aboutData.addAuthor(
         i18n("Elvis Angelaccio"),
         i18n("Maintainer"),
         QStringLiteral("elvis.angelaccio@kde.org"),
-        QStringLiteral("http://aelog.org")
+        QStringLiteral("https://eang.it")
     );
 
     aboutData.addCredit(
